@@ -2,13 +2,14 @@ import warnings
 from typing import TYPE_CHECKING, Any, Dict, List, Tuple, Type
 
 import duckdb
+from sqlalchemy import pool
 from sqlalchemy import types as sqltypes
 from sqlalchemy import util
 from sqlalchemy.dialects.postgresql import dialect as postgres_dialect
 from sqlalchemy.dialects.postgresql.base import PGExecutionContext, PGInspector
 from sqlalchemy.engine.url import URL
 
-__version__ = "0.2.0"
+__version__ = "0.3.1"
 
 if TYPE_CHECKING:
     from sqlalchemy.sql.ddl import ExecutableDDLElement  # type: ignore
@@ -19,8 +20,8 @@ class DBAPI:
     apilevel = duckdb.apilevel
     threadsafety = duckdb.threadsafety
 
-    class Error(Exception):
-        pass
+    # this is being fixed upstream to add a proper exception hierarchy
+    Error = RuntimeError
 
     @staticmethod
     def Binary(x: Any) -> Any:
@@ -184,6 +185,13 @@ class Dialect(postgres_dialect):
     ) -> None:
         cursor.execute(statement, parameters, context)
 
+    @classmethod
+    def get_pool_class(cls, url: URL) -> Type[pool.Pool]:
+        if url.database == ":memory:":
+            return pool.SingletonThreadPool
+        else:
+            return pool.QueuePool
+
     def do_executemany(
         self,
         cursor: ConnectionWrapper,
